KWTAMechanism
======================

.. automodule:: psyneulink.library.components.mechanisms.processing.transfer.kWTAMechanism
   :members:
   :private-members:
   :exclude-members: random, Parameters
